@@ -25,6 +25,11 @@ def resolve_address(address):
     return ip
 
 
+@sio.on("message")
+async def print_message(msg):
+    print(msg)
+
+
 @sio.on("designate")
 async def designate(virtual_ip):
     print(f"Virtual address: {virtual_ip}")
@@ -43,10 +48,11 @@ async def handle_incoming(data):
     # await asyncio.sleep(0.0)
 
 
-async def start_client(address, filter_string):
+async def start_client(address, requested_ip, filter_string):
+    headers = {"req_ip": requested_ip, "loc_ip": LOCAL_IP}
 
     try:
-        await sio.connect(f"{address}")
+        await sio.connect(f"{address}", auth=headers)
     except socketio.exceptions.ConnectionError:
         print(f"Unable to connect to the address {address}")
         exit()
@@ -68,7 +74,7 @@ async def start_client(address, filter_string):
         # await asyncio.sleep(0.0001)
 
 
-def start(address, filter_string=None, no_dns=False):
+def start(address, filter_string=None, requested_ip=None, no_dns=False):
     if filter_string is None:
         filter_string = f"outbound && !loopback && ip.DstAddr != {resolve_address(address)} && ip"
 
@@ -76,7 +82,7 @@ def start(address, filter_string=None, no_dns=False):
         filter_string = f"outbound && !loopback && ip.DstAddr != {resolve_address(address)} && (tcp || udp.DstPort != 53 || icmp)"
 
     try:
-        loop.run_until_complete(start_client(address, filter_string))
+        loop.run_until_complete(start_client(address, requested_ip, filter_string))
     except KeyboardInterrupt:
         _toori.stop()
         print("Exited, have a nice day :)")
